SharedState

Struct SharedState 

pub struct SharedState {
    pub peers: Arc<Mutex<HashMap<String, Peer>>>,
    pub known_peers: KnownPeers,
    pub shares: Shares,
    pub wishlist: WishList,
    pub event_broadcaster: Sender<UiEvent>,
    pub download_dir: PathBuf,
    pub name: String,
    pub announce_address: AnnounceAddress,
    pub os_home_dir: Option<String>,
    /* private fields */
}
Shared state used by both the peer connections and user interface server

Fields

peers: Arc<Mutex<HashMap<String, Peer>>>

A map of peer names to active peer connections

known_peers: KnownPeers

A list of known peer names

shares: Shares

The index of shared files

wishlist: WishList

Maintains lists of requested/downloaded files

event_broadcaster: Sender<UiEvent>

Channel for sending events to the UI

download_dir: PathBuf

Download directory

name: String

A name derived from our public key

announce_address: AnnounceAddress

Our own connection details

os_home_dir: Option<String>

Our OS home directory path

Implementations

Source

impl SharedState

pub async fn new( db: Db, share_dirs: Vec<String>, download_dir: PathBuf, name: String, peer_announce_tx: Sender<PeerConnect>, peers: Arc<Mutex<HashMap<String, Peer>>>, announce_address: AnnounceAddress, graceful_shutdown_tx: Sender<()>, known_peers: KnownPeers, ) -> Result<Self>

pub async fn send_event(&self, event: UiEvent)

Send an event to the UI

pub async fn request( &self, request: Request, name: &str, ) -> Result<RecvStream, RequestError>

Open a request stream and write a request to the peer with the given name

pub async fn request_peer( request: Request, peer: &Peer, ) -> Result<RecvStream, RequestError>

Static method to open a request stream and write a request to the given peer

pub fn get_ui_announce_address(&self) -> String

pub async fn connect_to_peer( &self, announce_address: AnnounceAddress, ) -> Result<(), UiServerErrorWrapper>

pub async fn download( &self, peer_path: PeerPath, ) -> Result<u32, UiServerErrorWrapper>

pub async fn shut_down(&self)

Gracefully shut down the process